/**
 * @file dmxstr.h
 * @author Florian Schmitt <florian.schmitt@qikgrp.com>
 * ----------------------------------------------------------------------------
 * (c) Florian Schmitt / 2012-2013
 * License GPLv3+: GNU GPL Version 3 
 * or higher <http://gnu.org/licenses/gpl.html>
 * This code comes with ABSOLUTELY NO WARRANTY. This is free software, and 
 * you are welcome to redistribute it under certain conditions.
 * ----------------------------------------------------------------------------
 * String operations
**/
#ifndef DMXSTR_H
#define DMXSTR_H
#include "midi/miditools.h"
#define DMXSTR_RANGE_SEPERATOR '-'
#define DMXSTR_DIR_SEPERATOR   '/'


/*
 * COMMON USEFUL STING FUNCTIONS
 */

/* is 1 if char is whitespace (tab or space) */
int dmxstr_isspace(char);
/* is 1 if char is end (zero, newline, linefeed) */
int dmxstr_isend(char);
/* check if char is numeric - second parameter: set 1 if hex allowed */
int dmxstr_isnumeral(char, int);
/* check if char is numeric */
int dmxstr_isnumber(const char*);
/* return string pointer without leading whitespace */
const char* dmxstr_remove_whitespace(const char*);
/* check if string is a comment or an empty line */
int dmxstr_is_comment(const char*);
/* converts steplength to readable string in measure-format */
int dmxstr_translate_steplen(char *strbuf, long int steplen);
/* get a file name by script dir and command name */
int dmxstr_get_script_filename(char*, int, const char*, const char*);
/* parses value into a string */
int dmxstr_parse_value(char*, const char*, midib);




/*
 * SPECIAL FUNCTIONS FOR COMMAND PARSING
 */

/* checks if a string is a command of given type */
const char* dmxstr_chkcmd(const char*, const char*);
/* gets next parameter or 0 none */
const char* dmxstr_get_next_param_str(const char*, char*, int);
/* gets next parameter or 0 if none - as integer */
const char* dmxstr_get_next_param_int(const char*, int*);
/* gets next parameter or 0 if none - as range */
const char* dmxstr_get_next_param_range(const char*, int*, int*);

#endif /* EXECUTOR_H */
