/**
 * @file global.c
 * @author Florian Schmitt <florian.schmitt@qikgrp.com>
 * ---------------------------------------------------------
 * (c) Florian Schmitt / Jan-2013 / All rights reserved. 
 * ---------------------------------------------------------
 * Provides gui content
**/
#include "global.h"
#include "dmxgui_tools.h"
#include "../cmdbuf.h"
#include "../executor.h"
#include "../dmxplayer.h"
#include <stdlib.h>
#include <string.h>


#define GLOBAL_MENU_CMD       (global_menu_sel == 0)
#define GLOBAL_MENU_FILENAME  (global_menu_sel == 1)
#define GLOBAL_MENU_LOAD      (global_menu_sel == 2)
#define GLOBAL_MENU_SAVE      (global_menu_sel == 3)

#define GLOBAL_MENU_MAX       3
int global_menu_sel = 0;
char returnbuffer[512];
char file_io_info[512];



/* A key event in active play mode */
void global_keyevent(int c, dmxgui_status_t *gui)
{
	int tmp;
	FILE *tf;
	returnbuffer[0] = '\0';
	file_io_info[0] = '\0';
	switch(c)
	{
		/* menu movements */
		case KEY_LEFT:
		case KEY_RIGHT:
			break;
		case KEY_UP:
			if(--global_menu_sel < 0) global_menu_sel = 0;
			break;
		case KEY_DOWN:
			if(++global_menu_sel > GLOBAL_MENU_MAX) global_menu_sel = GLOBAL_MENU_MAX;
			break;
		/* enter */
		case KEY_ENTER:
		case '\r':
		case '\n':
			if( GLOBAL_MENU_CMD || GLOBAL_MENU_FILENAME )
			{
				gui->is_user_input = 1;
			}
			else if( GLOBAL_MENU_LOAD )
			{
				tf = fopen(gui->filename, "rb");			
				if(tf == 0) 
				{
					sprintf(file_io_info, "ERROR: Not able to open/read file!");
					break;
				}
				dmxgui_load(tf);
				tmp = dmxplayer_load(tf);
				if(tmp >= 0) sprintf(file_io_info, "File loaded successfully");
				else sprintf(file_io_info, "Error reading file!");
				fclose(tf);
			}
			else if( GLOBAL_MENU_SAVE )
			{
				tf = fopen(gui->filename, "wb");				
				if(tf == 0) 
				{
					sprintf(file_io_info, "ERROR: Not able to write/create file!");
					break;
				}
				dmxgui_save(tf);
				tmp = dmxplayer_save(tf);
				if(tmp >= 0) sprintf(file_io_info, "File saved successfully");
				else sprintf(file_io_info, "Error writing file!");
				fclose(tf);
			}
			break;
		/* user input finished */
		case DMXGUI_KEY_INPUT_FIN:
			if( GLOBAL_MENU_CMD )
			{
				if(strcmp(gui->input, "exit") != 0)
				{
					if( (gui->input[0] != '\0') && (gui->input[0] != '\n') )
					{
						cmdbuf_printf("$ %s", gui->input);
						executor(gui->input, 1);
					}
					gui->is_user_input = 1;
				}
			}
			else if( GLOBAL_MENU_FILENAME )
			{
				sprintf(gui->filename, "%s", gui->input);
			}
			gui->input[0] = '\0';
			gui->inplen = 0;
			break;
	}
}


/**
 * Print programmer window 
 * @param wnd          Window
 * @param gui          GUI status info
**/
void global_printer(WINDOW* wnd, dmxgui_status_t *gui)
{
	int y, cmdline;
	/* draw window frame */
	wbkgd(wnd, COLOR_PAIR(1));
	box(wnd, 0, 0);
	y = 3;
	mvwprintw(wnd, y, 2, "Global Options (use enter to modify):");

	/* draw window content */
	wattron(wnd, COLOR_PAIR(2));

		/* show terminal */
		cmdline=LINES-22;
		if(cmdline < 4) cmdline = 4;
		if(cmdline > CMDBUF_BUF_LINES) cmdline = CMDBUF_BUF_LINES;
		for(; cmdline>0; cmdline--)
		{
			mvwhline(wnd, ++y, 2, ' ', (COLS-4));
			mvwprintw(wnd, y, 2, "| %s", cmdbuf_getline(CMDBUF_BUF_LINES-cmdline));
		}
		y += 1;

		/* cmd input draw */
		if(GLOBAL_MENU_CMD) 
		{
			wattron(wnd, A_REVERSE);
			mvwhline(wnd, y, 2, ' ', (COLS-4));
			if(gui->is_user_input) mvwprintw(wnd, y, 2, "  $ %s_", gui->input);
			else mvwprintw(wnd, y, 2, "  <press return to enter command>");
			wattroff(wnd, A_REVERSE);
			
		}
		else
		{
			mvwhline(wnd, y, 2, ' ', (COLS-4));
			mvwprintw(wnd, y, 2, "  $ ");
		}
		/* exit notice */
		if(gui->is_user_input)
		{
			mvwhline(wnd, ++y, 2, ' ', (COLS-4));
			mvwprintw(wnd, y, 2, "  (type exit to leave cmd)");
		}
		else
		{
			mvwhline(wnd, ++y, 2, ' ', (COLS-4));
		}

		/* filename selector draw */
		y += 2;
		mvwprintw(wnd, y, 2, "File to save to:");
		y++;
		mvwhline(wnd, y, 2, ' ', (COLS-4));
		if(GLOBAL_MENU_FILENAME) 
		{
			wattron(wnd, A_REVERSE);
			if(gui->is_user_input) mvwprintw(wnd, y, 2, " >%s< ", gui->input);
			else mvwprintw(wnd, y, 2, "  %s  ", gui->filename);
			wattroff(wnd, A_REVERSE);
		}
		else
		{
			mvwprintw(wnd, y, 2, "  %s", gui->filename);
		}

		/* LOAD COMMAND */
		y += 3;
		if(GLOBAL_MENU_LOAD) wattron(wnd, A_REVERSE);
		mvwprintw(wnd, y, 2, "Load from file");
		if(GLOBAL_MENU_LOAD) wattroff(wnd, A_REVERSE);

		/* SAVE COMMAND */
		y += 3;
		if(GLOBAL_MENU_SAVE) wattron(wnd, A_REVERSE);
		mvwprintw(wnd, y, 2, "Save to file");
		if(GLOBAL_MENU_SAVE) wattroff(wnd, A_REVERSE);

	wattroff(wnd, COLOR_PAIR(2));
	wattron(wnd, COLOR_PAIR(3));
		y += 4;
		mvwhline(wnd, y, 2, ' ', (COLS-4));
		mvwprintw(wnd, y, 2, "%s", file_io_info);
	wattroff(wnd, COLOR_PAIR(3));


	/* show key information */	
	dmxgui_print_key_bindings(wnd);
}


